@@ -16,10 +16,9 @@
 #         详细的授权流程，请联系 public@ricequant.com 获取。
 from __future__ import division
 
-from typing import Union, Optional, List, Callable
-from datetime import date, datetime
 import types
-from collections import Iterable
+from datetime import date, datetime
+from typing import Callable, List, Optional, Union, Iterable
 
 import pandas as pd
 import numpy as np
@@ -38,6 +37,7 @@ from rqalpha.model.instrument import Instrument
 from rqalpha.model.tick import TickObject
 from rqalpha.const import (
     EXECUTION_PHASE, ORDER_STATUS, SIDE, POSITION_EFFECT, ORDER_TYPE, MATCHING_TYPE, RUN_TYPE, POSITION_DIRECTION,
+    DEFAULT_ACCOUNT_TYPE
 )
 from rqalpha.model.order import Order, MarketOrder, LimitOrder, OrderStyle
 from rqalpha.core.events import EVENT, Event
@@ -140,8 +140,8 @@ def submit_order(id_or_ins, amount, side, price=None, position_effect=None):
     order_book_id = assure_order_book_id(id_or_ins)
     env = Environment.get_instance()
     if (
-        env.config.base.run_type != RUN_TYPE.BACKTEST
-        and env.get_instrument(order_book_id).type == "Future"
+            env.config.base.run_type != RUN_TYPE.BACKTEST
+            and env.get_instrument(order_book_id).type == "Future"
     ):
         if "88" in order_book_id:
             raise RQInvalidArgument(
@@ -372,7 +372,7 @@ def get_yield_curve(date=None, tenor=None):
 @apply_rules(
     verify_that("order_book_id", pre_check=True).is_listed_instrument(),
     verify_that("bar_count").is_instance_of(int).is_greater_than(0),
-    verify_that("frequency").is_valid_frequency(),
+    verify_that("frequency", pre_check=True).is_valid_frequency(),
     verify_that("fields").are_valid_fields(
         names.VALID_HISTORY_FIELDS, ignore_none=True
     ),
@@ -381,13 +381,13 @@ def get_yield_curve(date=None, tenor=None):
     verify_that("adjust_type").is_in({"pre", "none", "post"}),
 )
 def history_bars(
-    order_book_id,
-    bar_count,
-    frequency,
-    fields=None,
-    skip_suspended=True,
-    include_now=False,
-    adjust_type="pre",
+        order_book_id,
+        bar_count,
+        frequency,
+        fields=None,
+        skip_suspended=True,
+        include_now=False,
+        adjust_type="pre",
 ):
     # type:(str, int, str, Optional[Union[str, List[str]]], Optional[bool], Optional[bool], Optional[str]) -> np.ndarray
     """
@@ -424,7 +424,7 @@ def history_bars(
 
     :param order_book_id: 合约代码
     :param bar_count: 获取的历史数据数量，必填项
-    :param frequency: 获取数据什么样的频率进行。'1d'或'1m'分别表示每日和每分钟，必填项
+    :param frequency: 获取数据什么样的频率进行。'1d'、'1m' 和 '1w' 分别表示每日、每分钟和每周，必填项
     :param fields: 返回数据字段。必填项。见下方列表。
     :param skip_suspended: 是否跳过停牌数据
     :param include_now: 是否包含当前数据
@@ -462,9 +462,6 @@ def history_bars(
     env = Environment.get_instance()
     dt = env.calendar_dt
 
-    if frequency[-1] not in {"m", "d"}:
-        raise RQInvalidArgument("invalid frequency {}".format(frequency))
-
     if frequency[-1] == "m" and env.config.base.frequency == "1d":
         raise RQInvalidArgument("can not get minute history in day back test")
 
@@ -477,9 +474,9 @@ def history_bars(
     if frequency == "1d":
         sys_frequency = Environment.get_instance().config.base.frequency
         if (
-            sys_frequency in ["1m", "tick"]
-            and not include_now
-            and ExecutionContext.phase() != EXECUTION_PHASE.AFTER_TRADING
+                sys_frequency in ["1m", "tick"]
+                and not include_now
+                and ExecutionContext.phase() != EXECUTION_PHASE.AFTER_TRADING
         ) or (ExecutionContext.phase() in (EXECUTION_PHASE.BEFORE_TRADING, EXECUTION_PHASE.OPEN_AUCTION)):
             dt = env.data_proxy.get_previous_trading_date(env.trading_dt.date())
             # 当 EXECUTION_PHASE.BEFORE_TRADING 的时候，强制 include_now 为 False
@@ -590,7 +587,11 @@ def all_instruments(type=None, date=None):
 
     result = env.data_proxy.all_instruments(types, dt)
     if types is not None and len(types) == 1:
-        return pd.DataFrame([i.__dict__ for i in result])
+        data = []
+        for i in result:
+            instrument_dic = {k: v for k, v in i.__dict__.items() if not k.startswith("_")}
+            data.append(instrument_dic)
+        return pd.DataFrame(data)
 
     return pd.DataFrame(
         [
@@ -723,25 +724,6 @@ def get_next_trading_date(date, n=1):
     return Environment.get_instance().data_proxy.get_next_trading_date(date, n)
 
 
-@export_as_api
-@ExecutionContext.enforce_phase(
-    EXECUTION_PHASE.ON_BAR, EXECUTION_PHASE.ON_TICK, EXECUTION_PHASE.SCHEDULED
-)
-@apply_rules(
-    verify_that("series_name", pre_check=True).is_instance_of(str),
-    verify_that("value", pre_check=True).is_number(),
-)
-def plot(series_name, value):
-    # type: (str, float) -> None
-    """
-    在生成的图标结果中，某一个根线上增加一个点。
-
-    :param series_name: 序列名称
-    :param value: 值
-    """
-    Environment.get_instance().add_plot(series_name, value)
-
-
 @export_as_api
 @ExecutionContext.enforce_phase(
     EXECUTION_PHASE.BEFORE_TRADING,
@@ -797,7 +779,7 @@ def current_snapshot(id_or_symbol):
 def get_positions():
     # type: () -> List[Position]
     """
-    获取所有持仓对象列表，
+    获取所有持仓对象列表。
 
     :example:
 
@@ -805,8 +787,8 @@ def get_positions():
 
         [In] get_positions()
         [Out]
-        [BookingPosition({'order_book_id': '000014.XSHE', 'quantity': 100, 'direction': POSITION_DIRECTION.LONG, 'old_quantity': 0, 'trading_pnl': 1.0, 'avg_price': 9.56, 'last_price': 0, 'position_pnl': 0.0}),
-         BookingPosition({'order_book_id': '000010.XSHE', 'quantity': 100, 'direction': POSITION_DIRECTION.LONG, 'old_quantity': 0, 'trading_pnl': 0.0, 'avg_price': 3.09, 'last_price': 0, 'position_pnl': 0.0})]
+        [StockPosition(order_book_id=000001.XSHE, direction=LONG, quantity=1000, market_value=19520.0, trading_pnl=0.0, position_pnl=0),
+        StockPosition(order_book_id=RB2112, direction=SHORT, quantity=2, market_value=-111580.0, trading_pnl=0.0, position_pnl=0)]
 
     """
     portfolio = Environment.get_instance().portfolio
@@ -820,7 +802,7 @@ def get_positions():
 def get_position(order_book_id, direction=POSITION_DIRECTION.LONG):
     # type: (str, Optional[POSITION_DIRECTION]) -> Position
     """
-    获取某个标的的持仓对象，
+    获取某个标的的持仓对象。
 
     :param order_book_id: 标的编号
     :param direction: 持仓方向
@@ -829,9 +811,9 @@ def get_position(order_book_id, direction=POSITION_DIRECTION.LONG):
 
     ..  code-block:: python3
 
-        [In] get_position('000014.XSHE','long_positions")
+        [In] get_position('000001.XSHE', POSITION_DIRECTION.LONG)
         [Out]
-        [BookingPosition({'order_book_id': '000014.XSHE', 'quantity': 100, 'direction': POSITION_DIRECTION.LONG, 'old_quantity': 0, 'trading_pnl': 1.0, 'avg_price': 9.56, 'last_price': 0, 'position_pnl': 0.0})]
+        StockPosition(order_book_id=000001.XSHE, direction=LONG, quantity=268600, market_value=4995960.0, trading_pnl=0.0, position_pnl=0)
 
     """
     portfolio = Environment.get_instance().portfolio
@@ -869,3 +851,49 @@ def symbol(order_book_id, sep=", "):
     else:
         s = sep.join(symbol(item) for item in order_book_id)
         return s
+
+
+@export_as_api
+@ExecutionContext.enforce_phase(
+    EXECUTION_PHASE.OPEN_AUCTION,
+    EXECUTION_PHASE.ON_BAR,
+    EXECUTION_PHASE.ON_TICK,
+    EXECUTION_PHASE.SCHEDULED,
+    EXECUTION_PHASE.GLOBAL
+)
+def deposit(account_type, amount):
+    # type: (str, float) -> None
+    """
+    入金（增加账户资金）
+
+    :param account_type: 账户类型
+    :param amount: 增加金额
+    :return: None
+    """
+    env = Environment.get_instance()
+    return env.portfolio.deposit_withdraw(account_type, amount)
+
+
+@export_as_api
+@ExecutionContext.enforce_phase(
+    EXECUTION_PHASE.OPEN_AUCTION,
+    EXECUTION_PHASE.ON_BAR,
+    EXECUTION_PHASE.ON_TICK,
+    EXECUTION_PHASE.SCHEDULED,
+    EXECUTION_PHASE.GLOBAL
+)
+@apply_rules(
+    verify_that("account_type").is_in(DEFAULT_ACCOUNT_TYPE),
+    verify_that("amount").is_number(),
+)
+def withdraw(account_type, amount):
+    # type: (str, float) -> None
+    """
+    出金（减少账户资金）
+
+    :param account_type: 账户类型
+    :param amount: 减少金额
+    :return: None
+    """
+    env = Environment.get_instance()
+    return env.portfolio.deposit_withdraw(account_type, amount * -1)
