@@ -17,7 +17,9 @@
 
 import datetime
 import sys
+import traceback
 from pprint import pformat
+from itertools import chain
 
 import jsonpickle.ext.numpy as jsonpickle_numpy
 import logbook
@@ -39,7 +41,7 @@ from rqalpha.utils import RqAttrDict, create_custom_exception, init_rqdatac_env
 from rqalpha.utils.exception import CustomException, is_user_exc, patch_user_exc
 from rqalpha.utils.i18n import gettext as _
 from rqalpha.utils.log_capture import LogCapture
-from rqalpha.utils.logger import system_log, user_log, user_system_log
+from rqalpha.utils.logger import release_print, system_log, user_log, user_system_log
 from rqalpha.utils.persisit_helper import PersistHelper
 
 jsonpickle_numpy.register_handlers()
@@ -77,20 +79,20 @@ def init_persist_helper(env, ucontext, executor, config):
     if persist_provider is None:
         raise RuntimeError(_(u"Missing persist provider. You need to set persist_provider before use persist"))
     persist_helper = PersistHelper(persist_provider, env.event_bus, config.base.persist_mode)
+    for key, obj in chain([
+        ('user_context', ucontext),
+        ('global_vars', env.global_vars),
+        ('universe', env._universe),
+        ('portfolio', env.portfolio),
+        ('executor', executor),
+    ], ((key, obj) for key, obj in [
+        ('event_source', env.event_source),
+        ('broker', env.broker)
+    ] if isinstance(obj, Persistable)), ((
+        "mod_{}".format(name), mod
+    ) for name, mod in env.mod_dict.items() if isinstance(mod, Persistable))):
+        persist_helper.register(key, obj)
     env.set_persist_helper(persist_helper)
-    persist_helper.register('user_context', ucontext)
-    persist_helper.register('global_vars', env.global_vars)
-    persist_helper.register('universe', env._universe)
-    if isinstance(env.event_source, Persistable):
-        persist_helper.register('event_source', env.event_source)
-    persist_helper.register('portfolio', env.portfolio)
-    for name, module in env.mod_dict.items():
-        if isinstance(module, Persistable):
-            persist_helper.register('mod_{}'.format(name), module)
-    # broker will restore open orders from account
-    if isinstance(env.broker, Persistable):
-        persist_helper.register('broker', env.broker)
-    persist_helper.register('executor', executor)
     return persist_helper
 
 
@@ -182,11 +184,6 @@ def run(config, source_code=None, user_funcs=None):
         env.user_strategy = user_strategy
 
         env.event_bus.publish_event(Event(EVENT.BEFORE_STRATEGY_RUN))
-        if persist_helper:
-            with LogCapture(user_log) as log_capture:
-                user_strategy.init()
-        else:
-            user_strategy.init()
 
         if config.extra.context_vars:
             for k, v in config.extra.context_vars.items():
@@ -194,6 +191,12 @@ def run(config, source_code=None, user_funcs=None):
                     v = v.__dict__
                 setattr(ucontext, k, v)
 
+        if persist_helper:
+            with LogCapture(user_log) as log_capture:
+                user_strategy.init()
+        else:
+            user_strategy.init()
+
         if persist_helper:
             env.event_bus.publish_event(Event(EVENT.BEFORE_SYSTEM_RESTORED))
             restored_obj_state = persist_helper.restore(None)
@@ -205,7 +208,7 @@ def run(config, source_code=None, user_funcs=None):
                 # 未能恢复init相关数据 保留当前策略初始化变量(展示当前策略初始化日志)
                 log_capture.replay()
             else:
-                user_system_log.info(_('system restored'))
+                system_log.debug(_('system restored'))
             env.event_bus.publish_event(Event(EVENT.POST_SYSTEM_RESTORED))
 
         init_succeed = True
@@ -216,6 +219,7 @@ def run(config, source_code=None, user_funcs=None):
 
         if env.profile_deco:
             output_profile_result(env)
+        release_print(scope)
     except CustomException as e:
         if init_succeed and persist_helper and env.config.base.persist_mode == const.PERSIST_MODE.ON_CRASH:
             persist_helper.persist()
@@ -223,6 +227,8 @@ def run(config, source_code=None, user_funcs=None):
         code = _exception_handler(e)
         mod_handler.tear_down(code, e)
     except Exception as e:
+        system_log.error(traceback.format_exc())
+
         if init_succeed and persist_helper and env.config.base.persist_mode == const.PERSIST_MODE.ON_CRASH:
             persist_helper.persist()
 
