@@ -15,10 +15,11 @@
 #         在此前提下，对本软件的使用同样需要遵守 Apache 2.0 许可，Apache 2.0 许可与本许可冲突之处，以本许可为准。
 #         详细的授权流程，请联系 public@ricequant.com 获取。
 
-from typing import Tuple, Optional
 from datetime import date
-from rqalpha.utils.functools import lru_cache
 
+from decimal import Decimal
+
+from rqalpha.utils.functools import lru_cache
 from rqalpha.model.trade import Trade
 from rqalpha.const import POSITION_DIRECTION, SIDE, POSITION_EFFECT, DEFAULT_ACCOUNT_TYPE, INSTRUMENT_TYPE
 from rqalpha.environment import Environment
@@ -95,13 +96,14 @@ class StockPosition(Position):
 
     def before_trading(self, trading_date):
         # type: (date) -> float
-        if self.quantity == 0:
-            return 0
+        delta_cash = super(StockPosition, self).before_trading(trading_date)
+        if self.quantity == 0 and not self._dividend_receivable:
+            return delta_cash
         if self.direction != POSITION_DIRECTION.LONG:
             raise RuntimeError("direction of stock position {} is not supposed to be short".format(self._order_book_id))
         data_proxy = Environment.get_instance().data_proxy
         self._handle_dividend_book_closure(trading_date, data_proxy)
-        delta_cash = self._handle_dividend_payable(trading_date)
+        delta_cash += self._handle_dividend_payable(trading_date)
         self._handle_split(trading_date, data_proxy)
         return delta_cash
 
@@ -184,10 +186,14 @@ class StockPosition(Position):
         self._dividend_receivable = None
         if self.dividend_reinvestment:
             last_price = self.last_price
-            self.apply_trade(Trade.__from_create__(
-                None, last_price, dividend_value / last_price, SIDE.BUY, POSITION_EFFECT.OPEN, self._order_book_id
-            ))
-            return 0
+            amount = int(Decimal(dividend_value) / Decimal(last_price))
+            round_lot = self._instrument.round_lot
+            amount = int(Decimal(amount) / Decimal(round_lot)) * round_lot
+            if amount > 0:
+                self.apply_trade(Trade.__from_create__(
+                    None, last_price, amount, SIDE.BUY, POSITION_EFFECT.OPEN, self._order_book_id
+                ))
+            return dividend_value - amount * last_price
         else:
             return dividend_value
 
@@ -195,16 +201,20 @@ class StockPosition(Position):
         ratio = data_proxy.get_split_by_ex_date(self._order_book_id, trading_date)
         if ratio is None:
             return
-        self._today_quantity = int(self._today_quantity * ratio)
-        self._old_quantity = int(self._old_quantity * ratio)
-        self._logical_old_quantity = int(self._logical_old_quantity * ratio)
         self._avg_price /= ratio
+        self._last_price /= ratio
         self._prev_close /= ratio
+        ratio = Decimal(ratio)
+        self._today_quantity = int(Decimal(self._today_quantity) * ratio)
+        # int(6000 * 1.15) -> 6899
+        self._old_quantity = int(Decimal(self._old_quantity) * ratio)
+        self._logical_old_quantity = int(Decimal(self._logical_old_quantity) * ratio)
 
 
 class FuturePosition(Position):
     __repr_properties__ = (
-        "order_book_id", "direction", "old_quantity", "quantity", "margin", "market_value", "trading_pnl", "position_pnl"
+        "order_book_id", "direction", "old_quantity", "quantity", "margin", "market_value", "trading_pnl",
+        "position_pnl"
     )
     __instrument_types__ = [INSTRUMENT_TYPE.FUTURE]
 
@@ -285,7 +295,7 @@ class FuturePosition(Position):
                 order_book_id=self._order_book_id
             ))
             self._today_quantity = self._old_quantity = 0
-        self._avg_price = self._prev_close
+        self._avg_price = self.last_price
         return delta_cash
 
 
