@@ -4,16 +4,20 @@
 # 除非遵守当前许可，否则不得使用本软件。
 #
 #     * 非商业用途（非商业用途指个人出于非商业目的使用本软件，或者高校、研究所等非营利机构出于教育、科研等目的使用本软件）：
-#         遵守 Apache License 2.0（下称“Apache 2.0 许可”），您可以在以下位置获得 Apache 2.0 许可的副本：http://www.apache.org/licenses/LICENSE-2.0。
+#         遵守 Apache License 2.0（下称“Apache 2.0 许可”），
+#         您可以在以下位置获得 Apache 2.0 许可的副本：http://www.apache.org/licenses/LICENSE-2.0。
 #         除非法律有要求或以书面形式达成协议，否则本软件分发时需保持当前许可“原样”不变，且不得附加任何条件。
 #
 #     * 商业用途（商业用途指个人出于任何商业目的使用本软件，或者法人或其他组织出于任何目的使用本软件）：
-#         未经米筐科技授权，任何个人不得出于任何商业目的使用本软件（包括但不限于向第三方提供、销售、出租、出借、转让本软件、本软件的衍生产品、引用或借鉴了本软件功能或源代码的产品或服务），任何法人或其他组织不得出于任何目的使用本软件，否则米筐科技有权追究相应的知识产权侵权责任。
+#         未经米筐科技授权，任何个人不得出于任何商业目的使用本软件（包括但不限于向第三方提供、销售、出租、出借、转让本软件、
+#         本软件的衍生产品、引用或借鉴了本软件功能或源代码的产品或服务），任何法人或其他组织不得出于任何目的使用本软件，
+#         否则米筐科技有权追究相应的知识产权侵权责任。
 #         在此前提下，对本软件的使用同样需要遵守 Apache 2.0 许可，Apache 2.0 许可与本许可冲突之处，以本许可为准。
 #         详细的授权流程，请联系 public@ricequant.com 获取。
 
 import datetime
 import json
+from typing import List, Tuple, Callable, Optional
 
 from dateutil.parser import parse
 
@@ -21,7 +25,7 @@ from rqalpha.core.execution_context import ExecutionContext
 from rqalpha.environment import Environment
 from rqalpha.const import EXC_TYPE, EXECUTION_PHASE
 from rqalpha.core.events import EVENT
-from rqalpha.utils.py2 import signature
+from inspect import signature
 from rqalpha.utils.exception import patch_user_exc, ModifyExceptionFromType
 
 
@@ -50,12 +54,12 @@ def _verify_function(name, func):
 
 class Scheduler(object):
     def __init__(self, frequency):
-        self._registry = []
-        self._today = None
-        self._this_week = None
-        self._this_month = None
-        self._last_minute = 0
-        self._current_minute = 0
+        self._registry = []       # type: List[Tuple[Callable[[], bool], Callable[[], bool], Callable]]
+        self._today = None        # type: Optional[datetime.date]
+        self._this_week = None    # type: Optional[List[datetime.date]]
+        self._this_month = None   # type: Optional[List[datetime.date]]
+        self._last_minute = 0     # type: Optional[int]
+        self._current_minute = 0  # type: Optional[int]
         self._stage = None
         self._frequency = frequency
         self._trading_calendar = None
@@ -116,7 +120,9 @@ class Scheduler(object):
             return lambda: self._is_before_trading()
 
         if time_rule is not None and not isinstance(time_rule, int):
-            raise patch_user_exc(ValueError('invalid time_rule, "before_trading" or int expected, got {}'.format(repr(time_rule))))
+            raise patch_user_exc(ValueError(
+                'invalid time_rule, "before_trading" or int expected, got {}'.format(repr(time_rule))
+            ))
 
         time_rule = time_rule if time_rule else self._minutes_since_midnight(9, 31)
         return lambda: self._should_trigger(time_rule)
@@ -124,9 +130,7 @@ class Scheduler(object):
     @ExecutionContext.enforce_phase(EXECUTION_PHASE.ON_INIT)
     def run_daily(self, func, time_rule=None):
         _verify_function('run_daily', func)
-        self._registry.append((self._always_true,
-                               self._time_rule_for(time_rule),
-                               func))
+        self._registry.append((self._always_true, self._time_rule_for(time_rule), func))
 
     @ExecutionContext.enforce_phase(EXECUTION_PHASE.ON_INIT)
     def run_weekly(self, func, weekday=None, tradingday=None, time_rule=None):
