@@ -25,7 +25,6 @@ from rqalpha.model.trade import Trade
 from rqalpha.portfolio.account import Account
 from rqalpha.utils import is_valid_price
 from rqalpha.utils.i18n import gettext as _
-
 from .slippage import SlippageDecider
 
 
@@ -45,7 +44,7 @@ class DefaultMatcher(AbstractMatcher):
         self._volume_percent = mod_config.volume_percent
         self._price_limit = mod_config.price_limit
         self._liquidity_limit = mod_config.liquidity_limit and env.config.base.frequency == "tick"
-        self._inactive_limit = mod_config.inactive_limit
+        self._inactive_limit = env.config.base.frequency != 'tick' and mod_config.inactive_limit
         self._volume_limit = mod_config.volume_limit
         self._env = env  # type: Environment
         self._deal_price_decider = self._create_deal_price_decider(mod_config.matching_type)
@@ -53,11 +52,13 @@ class DefaultMatcher(AbstractMatcher):
     def _create_deal_price_decider(self, matching_type):
         decider_dict = {
             MATCHING_TYPE.CURRENT_BAR_CLOSE: self._current_bar_close_decider,
+            MATCHING_TYPE.VWAP: self._vwap_decider,
             MATCHING_TYPE.NEXT_BAR_OPEN: self._next_bar_open_decider,
             MATCHING_TYPE.NEXT_TICK_LAST: lambda order_book_id, side: self._env.price_board.get_last_price(
                 order_book_id),
             MATCHING_TYPE.NEXT_TICK_BEST_OWN: lambda order_book_id, side: self._best_own_price_decider(order_book_id,
                                                                                                        side),
+            MATCHING_TYPE.COUNTERPARTY_OFFER: None,
             MATCHING_TYPE.NEXT_TICK_BEST_COUNTERPARTY: lambda order_book_id, side: (
                 self._env.price_board.get_a1(order_book_id) if side == SIDE.BUY else self._env.price_board.get_b1(
                     order_book_id))
@@ -76,6 +77,14 @@ class DefaultMatcher(AbstractMatcher):
         except (KeyError, TypeError):
             return 0
 
+    def _vwap_decider(self, order_book_id, _):
+        try:
+            contract_multiplier = self._env.get_instrument(order_book_id).contract_multiplier
+            bar = self._env.get_bar(order_book_id)
+            return bar.total_turnover / bar.volume / contract_multiplier
+        except (KeyError, TypeError, ZeroDivisionError):
+            return 0
+
     def _best_own_price_decider(self, order_book_id, side):
         price = self._env.price_board.get_b1(order_book_id) if side == SIDE.BUY else self._env.price_board.get_a1(
             order_book_id)
@@ -164,9 +173,7 @@ class DefaultMatcher(AbstractMatcher):
         if self._inactive_limit:
             bar_volume = self._env.get_bar(order_book_id).volume
             if bar_volume == 0:
-                reason = _(u"Order Cancelled: {order_book_id} bar volume = {volume} "). \
-                    format(order_book_id=order.order_book_id,
-                           volume=bar_volume)
+                reason = _(u"Order Cancelled: {order_book_id} bar no volume").format(order_book_id=order.order_book_id)
                 order.mark_cancelled(reason)
                 return
 
@@ -230,3 +237,116 @@ class DefaultMatcher(AbstractMatcher):
 
     def update(self):
         self._turnover.clear()
+
+
+class CounterPartyOfferMatcher(DefaultMatcher):
+    def __init__(self, env, mod_config):
+        super(CounterPartyOfferMatcher, self).__init__(env, mod_config)
+        self._env = env
+        self._a_volume = {}
+        self._b_volume = {}
+        self._a_price = {}
+        self._b_price = {}
+        self._env.event_bus.add_listener(EVENT.TICK, self._pre_tick)
+
+    def match(self, account, order, open_auction):
+        # type: (Account, Order, bool) -> None
+        #
+        """限价撮合：
+        订单买价>卖x价
+        买量>卖x量，按照卖x价成交，订单减去卖x量，继续撮合卖x+1，直至该tick中所有报价被买完。买完后若有剩余买量，则在下一个tick继续撮合。
+        买量<卖x量，按照卖x价成交。
+        反之亦然
+        市价单：
+        按照该tick，a1，b1进行成交，剩余订单直接撤单
+        """
+        order_book_id = order.order_book_id
+
+        self._pop_volume_and_price(order)
+        if order.side == SIDE.BUY:
+            if len(self._a_volume[order_book_id]) == 0:
+                return
+            volume_limit = self._a_volume[order_book_id][0]
+            matching_price = self._a_price[order_book_id][0]
+        else:
+            if len(self._b_volume[order_book_id]) == 0:
+                return
+            volume_limit = self._b_volume[order_book_id][0]
+            matching_price = self._b_price[order_book_id][0]
+
+        if order.type == ORDER_TYPE.MARKET:
+            amount = volume_limit
+        else:
+            if volume_limit != volume_limit:
+                return
+            amount = volume_limit
+            if amount == 0.0 and order.unfilled_quantity != 0:
+                # if order.unfilled_quantity != 0:
+                return self.match(account, order, open_auction)
+
+        if matching_price != matching_price:
+            return
+
+        if not (order.position_effect in self.SUPPORT_POSITION_EFFECTS and order.side in self.SUPPORT_SIDES):
+            raise NotImplementedError
+        if order.type == ORDER_TYPE.LIMIT:
+            if order.side == SIDE.BUY and order.price < matching_price:
+                return
+            if order.side == SIDE.SELL and order.price > matching_price:
+                return
+        fill = order.unfilled_quantity
+        ct_amount = account.calc_close_today_amount(order_book_id, fill, order.position_direction)
+
+        trade = Trade.__from_create__(
+            order_id=order.order_id,
+            price=matching_price,
+            amount=min(amount, fill),
+            side=order.side,
+            position_effect=order.position_effect,
+            order_book_id=order.order_book_id,
+            frozen_price=order.frozen_price,
+            close_today_amount=ct_amount
+        )
+        trade._commission = self._env.get_trade_commission(trade)
+        trade._tax = self._env.get_trade_tax(trade)
+        order.fill(trade)
+        self._env.event_bus.publish_event(Event(EVENT.TRADE, account=account, trade=trade, order=order))
+
+        if order.side == SIDE.BUY:
+            self._a_volume[order.order_book_id][0] -= min(amount, fill)
+        else:
+            self._b_volume[order.order_book_id][0] -= min(amount, fill)
+
+        if order.type == ORDER_TYPE.MARKET and order.unfilled_quantity != 0:
+            reason = _("Order Cancelled: market order {order_book_id} fill {filled_volume} actually").format(
+                order_book_id=order.order_book_id,
+                filled_volume=order.filled_quantity,
+            )
+            order.mark_cancelled(reason)
+            return
+        if order.unfilled_quantity != 0:
+            self.match(account, order, open_auction)
+
+    def _pop_volume_and_price(self, order):
+        try:
+            if order.side == SIDE.BUY:
+                if self._a_volume[order.order_book_id][0] == 0:
+                    self._a_volume[order.order_book_id].pop(0)
+                    self._a_price[order.order_book_id].pop(0)
+            else:
+                if self._b_volume[order.order_book_id][0] == 0:
+                    self._b_volume[order.order_book_id].pop(0)
+                    self._b_price[order.order_book_id].pop(0)
+        except IndexError:
+            return
+
+    def _pre_tick(self, event):
+        order_book_id = event.tick.order_book_id
+        self._a_volume[order_book_id] = event.tick.ask_vols
+        self._b_volume[order_book_id] = event.tick.bid_vols
+
+        self._a_price[order_book_id] = event.tick.asks
+        self._b_price[order_book_id] = event.tick.bids
+
+    def update(self):
+        pass
