@@ -42,11 +42,11 @@ class SignalBroker(AbstractBroker):
         if order.position_effect == POSITION_EFFECT.EXERCISE:
             raise NotImplementedError("SignalBroker does not support exercise order temporarily")
         account = self._env.get_account(order.order_book_id)
-        self._env.event_bus.publish_event(Event(EVENT.ORDER_PENDING_NEW, account=account, order=copy(order)))
+        self._env.event_bus.publish_event(Event(EVENT.ORDER_PENDING_NEW, account=account, order=order))
         if order.is_final():
             return
         order.active()
-        self._env.event_bus.publish_event(Event(EVENT.ORDER_CREATION_PASS, account=account, order=copy(order)))
+        self._env.event_bus.publish_event(Event(EVENT.ORDER_CREATION_PASS, account=account, order=order))
         self._match(account, order)
 
     def cancel_order(self, order):
@@ -81,23 +81,24 @@ class SignalBroker(AbstractBroker):
             deal_price = last_price
 
         if self._price_limit:
-            """
-            在 Signal 模式下，不再阻止涨跌停是否买进，price_limit 参数表示是否给出警告提示。
-            """
             if order.position_effect != POSITION_EFFECT.EXERCISE:
                 if order.side == SIDE.BUY and deal_price >= price_board.get_limit_up(order_book_id):
-                    user_system_log.warning(
-                        _(u"You have traded {order_book_id} with {quantity} lots in limit up status").format(
-                            order_book_id=order_book_id, quantity=order.quantity
-                        )
-                    )
+                    order.mark_rejected(_(
+                        "Order Cancelled: current bar [{order_book_id}] reach the limit_up price."
+                    ).format(order_book_id=order.order_book_id))
+                    self._env.event_bus.publish_event(Event(
+                        EVENT.ORDER_UNSOLICITED_UPDATE, account=account, order=copy(order)
+                    ))
+                    return
 
                 if order.side == SIDE.SELL and deal_price <= price_board.get_limit_down(order_book_id):
-                    user_system_log.warning(
-                        _(u"You have traded {order_book_id} with {quantity} lots in limit down status").format(
-                            order_book_id=order_book_id, quantity=order.quantity
-                        )
-                    )
+                    order.mark_rejected(_(
+                        "Order Cancelled: current bar [{order_book_id}] reach the limit_down price."
+                    ).format(order_book_id=order.order_book_id))
+                    self._env.event_bus.publish_event(Event(
+                        EVENT.ORDER_UNSOLICITED_UPDATE, account=account, order=copy(order)
+                    ))
+                    return
 
         ct_amount = account.calc_close_today_amount(order_book_id, order.quantity, order.position_direction)
         trade_price = self._slippage_decider.get_trade_price(order, deal_price)
