@@ -30,7 +30,7 @@ from rqalpha.const import MATCHING_TYPE, ORDER_STATUS, POSITION_EFFECT, EXECUTIO
 from rqalpha.model.order import Order
 from rqalpha.environment import Environment
 
-from .matcher import DefaultMatcher, AbstractMatcher
+from .matcher import DefaultMatcher, AbstractMatcher, CounterPartyOfferMatcher
 
 
 class SimulationBroker(AbstractBroker, Persistable):
@@ -40,15 +40,17 @@ class SimulationBroker(AbstractBroker, Persistable):
 
         self._matchers = {}  # type: Dict[INSTRUMENT_TYPE, AbstractMatcher]
 
-        self._match_immediately = mod_config.matching_type == MATCHING_TYPE.CURRENT_BAR_CLOSE
+        self._match_immediately = mod_config.matching_type in [MATCHING_TYPE.CURRENT_BAR_CLOSE, MATCHING_TYPE.VWAP]
 
         self._open_orders = []  # type: List[Tuple[Account, Order]]
-        self._open_auction_orders = []   # type: List[Tuple[Account, Order]]
+        self._open_auction_orders = []  # type: List[Tuple[Account, Order]]
         self._open_exercise_orders = []  # type: List[Tuple[Account, Order]]
 
-        self._delayed_orders = []
         self._frontend_validator = {}
 
+        if self._mod_config.matching_type == MATCHING_TYPE.COUNTERPARTY_OFFER:
+            for instrument_type in INSTRUMENT_TYPE:
+                self.register_matcher(instrument_type, CounterPartyOfferMatcher(self._env, self._mod_config))
         # 该事件会触发策略的before_trading函数
         self._env.event_bus.add_listener(EVENT.BEFORE_TRADING, self.before_trading)
         # 该事件会触发策略的handle_bar函数
@@ -74,14 +76,14 @@ class SimulationBroker(AbstractBroker, Persistable):
 
     def get_open_orders(self, order_book_id=None):
         if order_book_id is None:
-            return [order for account, order in self._open_orders]
+            return [order for account, order in chain(self._open_orders, self._open_auction_orders)]
         else:
-            return [order for account, order in self._open_orders if order.order_book_id == order_book_id]
+            return [order for account, order in chain(self._open_orders, self._open_auction_orders) if
+                    order.order_book_id == order_book_id]
 
     def get_state(self):
         return jsonpickle.dumps({
             'open_orders': [o.get_state() for account, o in self._open_orders],
-            'delayed_orders': [o.get_state() for account, o in self._delayed_orders],
             "open_auction_orders": [o.get_state() for account, o in self._open_auction_orders],
         }).encode('utf-8')
 
@@ -94,10 +96,10 @@ class SimulationBroker(AbstractBroker, Persistable):
 
         value = jsonpickle.loads(state.decode('utf-8'))
         self._open_orders = [_account_order_from_state(v) for v in value["open_orders"]]
-        self._delayed_orders = [_account_order_from_state(v) for v in value["delayed_orders"]]
         self._open_auction_orders = [_account_order_from_state(v) for v in value.get("open_auction_orders", [])]
 
     def submit_order(self, order):
+        self._check_subscribe(order)
         if order.position_effect == POSITION_EFFECT.MATCH:
             raise TypeError(_("unsupported position_effect {}").format(order.position_effect))
         account = self._env.get_account(order.order_book_id)
@@ -109,9 +111,6 @@ class SimulationBroker(AbstractBroker, Persistable):
         if ExecutionContext.phase() == EXECUTION_PHASE.OPEN_AUCTION:
             self._open_auction_orders.append((account, order))
         else:
-            if self._env.config.base.frequency == '1d' and not self._match_immediately:
-                self._delayed_orders.append((account, order))
-                return
             self._open_orders.append((account, order))
         order.active()
         self._env.event_bus.publish_event(Event(EVENT.ORDER_CREATION_PASS, account=account, order=order))
@@ -130,10 +129,7 @@ class SimulationBroker(AbstractBroker, Persistable):
         try:
             self._open_orders.remove((account, order))
         except ValueError:
-            try:
-                self._delayed_orders.remove((account, order))
-            except ValueError:
-                pass
+            pass
 
     def before_trading(self, _):
         for account, order in self._open_orders:
@@ -146,8 +142,7 @@ class SimulationBroker(AbstractBroker, Persistable):
                 order_book_id=order.order_book_id
             ))
             self._env.event_bus.publish_event(Event(EVENT.ORDER_UNSOLICITED_UPDATE, account=account, order=order))
-        self._open_orders = self._delayed_orders
-        self._delayed_orders = []
+        self._open_orders = []
 
     def pre_settlement(self, __):
         for account, order in self._open_exercise_orders:
@@ -177,3 +172,8 @@ class SimulationBroker(AbstractBroker, Persistable):
         for account, order in final_orders:
             if order.status == ORDER_STATUS.REJECTED or order.status == ORDER_STATUS.CANCELLED:
                 self._env.event_bus.publish_event(Event(EVENT.ORDER_UNSOLICITED_UPDATE, account=account, order=order))
+
+    def _check_subscribe(self, order):
+        if self._env.config.base.frequency == "tick" and order.order_book_id not in self._env.get_universe():
+            raise RuntimeError(_("{order_book_id} should be subscribed when frequency is tick.").format(
+                order_book_id=order.order_book_id))
