@@ -15,17 +15,14 @@
 #         在此前提下，对本软件的使用同样需要遵守 Apache 2.0 许可，Apache 2.0 许可与本许可冲突之处，以本许可为准。
 #         详细的授权流程，请联系 public@ricequant.com 获取。
 
-from itertools import chain
 from datetime import timedelta, datetime, time
 
-import pandas
-
 from rqalpha.environment import Environment
 from rqalpha.interface import AbstractEventSource
 from rqalpha.core.events import Event, EVENT
 from rqalpha.utils.exception import patch_user_exc
 from rqalpha.utils.datetime_func import convert_int_to_datetime
-from rqalpha.const import DEFAULT_ACCOUNT_TYPE, MARKET, TRADING_CALENDAR_TYPE
+from rqalpha.const import DEFAULT_ACCOUNT_TYPE
 from rqalpha.utils.i18n import gettext as _
 
 
@@ -37,14 +34,8 @@ class SimulationEventSource(AbstractEventSource):
         self._universe_changed = False
         self._env.event_bus.add_listener(EVENT.POST_UNIVERSE_CHANGED, self._on_universe_changed)
 
-        if self._config.base.market == MARKET.CN:
-            self._get_day_bar_dt = lambda date: date.replace(hour=15, minute=0)
-            self._get_after_trading_dt = lambda date: date.replace(hour=15, minute=30)
-        elif self._config.base.market == MARKET.HK:
-            self._get_day_bar_dt = lambda date: date.replace(hour=16, minute=6)
-            self._get_after_trading_dt = lambda date: date.replace(hour=16, minute=30)
-        else:
-            raise NotImplementedError(_("Unsupported market {}".format(self._config.base.market)))
+        self._get_day_bar_dt = lambda date: date.replace(hour=15, minute=0)
+        self._get_after_trading_dt = lambda date: date.replace(hour=15, minute=30)
 
     def _on_universe_changed(self, _):
         self._universe_changed = True
@@ -61,18 +52,10 @@ class SimulationEventSource(AbstractEventSource):
     def _get_stock_trading_minutes(self, trading_date):
         trading_minutes = set()
 
-        if self._env.config.base.market == MARKET.CN:
-            current_dt = datetime.combine(trading_date, time(9, 31))
-            am_end_dt = current_dt.replace(hour=11, minute=30)
-            pm_start_dt = current_dt.replace(hour=13, minute=1)
-            pm_end_dt = current_dt.replace(hour=15, minute=0)
-        elif self._env.config.base.market == MARKET.HK:
-            current_dt = datetime.combine(trading_date, time(9, 31))
-            am_end_dt = current_dt.replace(hour=12, minute=0)
-            pm_start_dt = current_dt.replace(hour=13, minute=1)
-            pm_end_dt = current_dt.replace(hour=16, minute=0)
-        else:
-            raise NotImplementedError(_("Unsupported market {}".format(self._env.config.base.market)))
+        current_dt = datetime.combine(trading_date, time(9, 31))
+        am_end_dt = current_dt.replace(hour=11, minute=30)
+        pm_start_dt = current_dt.replace(hour=13, minute=1)
+        pm_end_dt = current_dt.replace(hour=15, minute=0)
 
         delta_minute = timedelta(minutes=1)
         while current_dt <= am_end_dt:
@@ -104,23 +87,8 @@ class SimulationEventSource(AbstractEventSource):
         return sorted(list(trading_minutes))
     # [END] minute event helper
 
-    def _get_merged_trading_dates(self, start_date, end_date, trading_calendar_types):
-        if len(trading_calendar_types) == 1:
-            return self._env.data_proxy.get_trading_dates(start_date, end_date, trading_calendar_types[0])
-        trading_calendars = []
-        for calendar_type in trading_calendar_types:
-            trading_calendars.append(self._env.data_proxy.get_trading_dates(start_date, end_date, calendar_type))
-        return pandas.DatetimeIndex(chain(*trading_calendars)).unique()
-
     def events(self, start_date, end_date, frequency):
-        calendar_types = []
-        for account_type in self._config.base.accounts:
-            if account_type in (DEFAULT_ACCOUNT_TYPE.STOCK, DEFAULT_ACCOUNT_TYPE.FUTURE):
-                calendar_types.append(TRADING_CALENDAR_TYPE.EXCHANGE)
-            elif account_type == DEFAULT_ACCOUNT_TYPE.BOND:
-                calendar_types.append(TRADING_CALENDAR_TYPE.INTER_BANK)
-        trading_dates = self._get_merged_trading_dates(start_date, end_date, calendar_types)
-
+        trading_dates = self._env.data_proxy.get_trading_dates(start_date, end_date)
         if frequency == "1d":
             # 根据起始日期和结束日期，获取所有的交易日，然后再循环获取每一个交易日
             for day in trading_dates:
