@@ -15,9 +15,8 @@
 #         在此前提下，对本软件的使用同样需要遵守 Apache 2.0 许可，Apache 2.0 许可与本许可冲突之处，以本许可为准。
 #         详细的授权流程，请联系 public@ricequant.com 获取。
 
-from rqalpha.utils.functools import lru_cache
-
 import six
+from datetime import datetime
 import numpy as np
 
 from rqalpha.core.execution_context import ExecutionContext
@@ -28,10 +27,9 @@ from rqalpha.utils.i18n import gettext as _
 from rqalpha.utils.logger import system_log
 from rqalpha.utils.exception import patch_user_exc
 from rqalpha.utils.repr import PropertyReprMeta
+from rqalpha.utils.class_helper import cached_property
 from rqalpha.const import EXECUTION_PHASE
 
-from .tick import TickObject
-
 NAMES = ['open', 'close', 'low', 'high', 'settlement', 'limit_up', 'limit_down', 'volume', 'total_turnover',
          'discount_rate', 'acc_net_value', 'unit_net_value', 'open_interest',
          'basis_spread', 'prev_settlement', 'datetime']
@@ -39,60 +37,55 @@ NANDict = {i: np.nan for i in NAMES}
 
 
 class PartialBarObject(metaclass=PropertyReprMeta):
+    # 用于 open_auction
     __repr_properties__ = (
-        "order_book_id", "datetime", "open", "limit_up", "limit_down"
+        "order_book_id", "datetime", "open", "limit_up", "limit_down", "last"
     )
 
-    order_book_id = property(lambda self: self._tick.order_book_id)
-    datetime = property(lambda self: self._tick.datetime)
-    open = property(fget=lambda self: self._tick.open)
-    limit_up = property(lambda self: self._tick.limit_up)
-    limit_down = property(lambda self: self._tick.limit_down)
-    last = property(lambda self: self.open)
-    volume = property(lambda self: self._tick.volume)
-    prev_close = property(lambda self: self._tick.prev_close)
-    prev_settlement = property(lambda self: self._tick.prev_settlement)
-    isnan = property(lambda self: self._tick.isnan)
-
-    def __init__(self, tick):
-        self._tick = tick  # type: TickObject
-
-
-class BarObject(object):
     def __init__(self, instrument, data, dt=None):
         self._dt = dt
         self._data = data if data is not None else NANDict
         self._instrument = instrument
+        self._env = Environment.get_instance()
 
-    @property
+    @cached_property
+    def datetime(self):
+        """
+        [datetime.datetime] 时间戳
+        """
+        if self._dt is not None:
+            return self._dt
+        dt = self._data["datetime"]
+        if isinstance(dt, datetime):
+            return dt
+        return convert_int_to_datetime(dt)
+
+    @cached_property
+    def instrument(self):
+        return self._instrument
+
+    @cached_property
+    def order_book_id(self):
+        """
+        [str] 交易标的代码
+        """
+        return self._instrument.order_book_id
+
+    @cached_property
+    def symbol(self):
+        """
+        [str] 合约简称
+        """
+        return self._instrument.symbol
+
+    @cached_property
     def open(self):
         """
         [float] 开盘价
         """
         return self._data["open"]
 
-    @property
-    def close(self):
-        """
-        [float] 收盘价
-        """
-        return self._data["close"]
-
-    @property
-    def low(self):
-        """
-        [float] 最低价
-        """
-        return self._data["low"]
-
-    @property
-    def high(self):
-        """
-        [float] 最高价
-        """
-        return self._data["high"]
-
-    @property
+    @cached_property
     def limit_up(self):
         """
         [float] 涨停价
@@ -103,7 +96,7 @@ class BarObject(object):
         except (KeyError, ValueError):
             return np.nan
 
-    @property
+    @cached_property
     def limit_down(self):
         """
         [float] 跌停价
@@ -114,8 +107,28 @@ class BarObject(object):
         except (KeyError, ValueError):
             return np.nan
 
-    @property
-    @lru_cache(None)
+    @cached_property
+    def last(self):
+        """
+        [float] 当前最新价
+        """
+        return self._data["last"]
+
+    @cached_property
+    def volume(self):
+        """
+        [float] 截止到当前的成交量
+        """
+        return self._data["volume"]
+
+    @cached_property
+    def total_turnover(self):
+        """
+        [float] 截止到当前的成交额
+        """
+        return self._data['total_turnover']
+
+    @cached_property
     def prev_close(self):
         """
         [float] 昨日收盘价
@@ -123,40 +136,65 @@ class BarObject(object):
         try:
             return self._data['prev_close']
         except (ValueError, KeyError):
-            trading_dt = Environment.get_instance().trading_dt
-            data_proxy = Environment.get_instance().data_proxy
-            return data_proxy.get_prev_close(self._instrument.order_book_id, trading_dt)
+            return self._env.data_proxy.get_prev_close(self._instrument.order_book_id, self._env.trading_dt)
 
-    @property
+    @cached_property
+    def prev_settlement(self):
+        """
+        [float] 昨日结算价（期货专用）
+        """
+        try:
+            return self._data['prev_settlement']
+        except (ValueError, KeyError):
+            return self._env.data_proxy.get_prev_settlement(self._instrument.order_book_id, self._env.trading_dt)
+
+    @cached_property
+    def isnan(self):
+        return np.isnan(self._data['close'])
+
+
+class BarObject(PartialBarObject):
+    __repr_properties__ = (
+        "order_book_id", "datetime", "open", "close", "high", "low", "limit_up", "limit_down"
+    )
+
+    @cached_property
+    def close(self):
+        """
+        [float] 收盘价
+        """
+        return self._data["close"]
+
+    @cached_property
+    def low(self):
+        """
+        [float] 最低价
+        """
+        return self._data["low"]
+
+    @cached_property
+    def high(self):
+        """
+        [float] 最高价
+        """
+        return self._data["high"]
+
+    @cached_property
     def last(self):
         """
         [float] 当前最新价
         """
         return self.close
 
-    @property
-    def volume(self):
-        """
-        [float] 截止到当前的成交量
-        """
-        return self._data["volume"]
-
-    @property
-    def total_turnover(self):
-        """
-        [float] 截止到当前的成交额
-        """
-        return self._data['total_turnover']
-
-    @property
+    @cached_property
     def discount_rate(self):
         return self._data['discount_rate']
 
-    @property
+    @cached_property
     def acc_net_value(self):
         return self._data['acc_net_value']
 
-    @property
+    @cached_property
     def unit_net_value(self):
         return self._data['unit_net_value']
 
@@ -166,8 +204,7 @@ class BarObject(object):
         'IC': '000905.XSHG',
     }
 
-    @property
-    @lru_cache(None)
+    @cached_property
     def basis_spread(self):
         try:
             return self._data['basis_spread']
@@ -181,72 +218,32 @@ class BarObject(object):
             else:
                 return np.nan
 
-    @property
+    @cached_property
     def settlement(self):
         """
         [float] 结算价（期货专用）
         """
         return self._data['settlement']
 
-    @property
-    @lru_cache(None)
-    def prev_settlement(self):
-        """
-        [float] 昨日结算价（期货专用）
-        """
-        try:
-            return self._data['prev_settlement']
-        except (ValueError, KeyError):
-            trading_dt = Environment.get_instance().trading_dt
-            data_proxy = Environment.get_instance().data_proxy
-            return data_proxy.get_prev_settlement(self._instrument.order_book_id, trading_dt)
-
-    @property
+    @cached_property
     def open_interest(self):
         """
         [float] 截止到当前的持仓量（期货专用）
         """
         return self._data['open_interest']
 
-    @property
-    def datetime(self):
-        """
-        [datetime.datetime] 时间戳
-        """
-        if self._dt is not None:
-            return self._dt
-        return convert_int_to_datetime(self._data['datetime'])
-
-    @property
-    def instrument(self):
-        return self._instrument
-
-    @property
-    def order_book_id(self):
-        """
-        [str] 交易标的代码
-        """
-        return self._instrument.order_book_id
-
-    @property
-    def symbol(self):
-        """
-        [str] 合约简称
-        """
-        return self._instrument.symbol
-
-    @property
+    @cached_property
     def is_trading(self):
         """
         [bool] 是否有成交量
         """
         return self._data['volume'] > 0
 
-    @property
+    @cached_property
     def isnan(self):
         return np.isnan(self._data['close'])
 
-    @property
+    @cached_property
     def suspended(self):
         if self.isnan:
             return True
@@ -313,9 +310,13 @@ class BarObject(object):
 
     def __getattr__(self, item):
         try:
-            return self._data[item]
+            value = self._data[item]
         except KeyError:
             raise AttributeError("'{}' object has no attribute '{}'".format(self.__class__.__name__, item))
+        else:
+            if isinstance(value, bytes):
+                return value.decode("utf-8")
+            return value
 
 
 class BarMap(object):
@@ -374,7 +375,7 @@ class BarMap(object):
                 self._cache[order_book_id] = bar
                 return bar
 
-    @property
+    @cached_property
     def dt(self):
         return self._dt
 
