@@ -15,24 +15,24 @@
 #         在此前提下，对本软件的使用同样需要遵守 Apache 2.0 许可，Apache 2.0 许可与本许可冲突之处，以本许可为准。
 #         详细的授权流程，请联系 public@ricequant.com 获取。
 
-from rqalpha.utils.functools import lru_cache
-from typing import Dict, Union, Callable, List, Tuple
 from itertools import chain
+from typing import Callable, Dict, List, Tuple, Union
 
-import six
 import jsonpickle
 import numpy as np
+import six
 
-from rqalpha.environment import Environment
 from rqalpha.const import DAYS_CNT, DEFAULT_ACCOUNT_TYPE, POSITION_DIRECTION
-from rqalpha.utils import merge_dicts
-from rqalpha.utils.repr import PropertyReprMeta
+from rqalpha.environment import Environment
 from rqalpha.core.events import EVENT
-from rqalpha.model.order import OrderStyle, Order
 from rqalpha.interface import AbstractPosition
-
-from .account import Account
-from .position import PositionType, PositionProxyType
+from rqalpha.model.order import Order, OrderStyle
+from rqalpha.portfolio.account import Account
+from rqalpha.utils import merge_dicts
+from rqalpha.utils.functools import lru_cache
+from rqalpha.utils.i18n import gettext as _
+from rqalpha.utils.logger import user_log
+from rqalpha.utils.repr import PropertyReprMeta
 
 OrderApiType = Callable[[str, Union[int, float], OrderStyle, bool], List[Order]]
 
@@ -48,7 +48,6 @@ class Portfolio(object, metaclass=PropertyReprMeta):
     def __init__(self, starting_cash, init_positions):
         # type: (Dict[str, float], List[Tuple[str, int]]) -> Portfolio
         self._static_unit_net_value = 1
-        self._last_unit_net_value = 1
 
         account_args = {}
         for account_type, cash in starting_cash.items():
@@ -60,12 +59,12 @@ class Portfolio(object, metaclass=PropertyReprMeta):
         self._accounts = {account_type: Account(**args) for account_type, args in account_args.items()}
         self._units = sum(account.total_value for account in six.itervalues(self._accounts))
 
-        self._register_event()
+        event_bus = Environment.get_instance().event_bus
+        event_bus.prepend_listener(EVENT.PRE_BEFORE_TRADING, self._pre_before_trading)
 
     def get_state(self):
         return jsonpickle.encode({
             'static_unit_net_value': self._static_unit_net_value,
-            'last_unit_net_value': self._last_unit_net_value,
             'units': self._units,
             'accounts': {
                 name: account.get_state() for name, account in self._accounts.items()
@@ -76,7 +75,6 @@ class Portfolio(object, metaclass=PropertyReprMeta):
         state = state.decode('utf-8')
         value = jsonpickle.decode(state)
         self._static_unit_net_value = value['static_unit_net_value']
-        self._last_unit_net_value = value.get('last_unit_net_value', self._static_unit_net_value)
         self._units = value['units']
         for k, v in value['accounts'].items():
             self._accounts[k].set_state(v)
@@ -138,9 +136,9 @@ class Portfolio(object, metaclass=PropertyReprMeta):
         """
         [float] 实时净值
         """
-        if self._units == 0:
+        if self.units == 0:
             return np.nan
-        return self.total_value / self._units
+        return self.total_value / self.units
 
     @property
     def static_unit_net_value(self):
@@ -247,18 +245,19 @@ class Portfolio(object, metaclass=PropertyReprMeta):
         return sum(account.frozen_cash for account in six.itervalues(self._accounts))
 
     def _pre_before_trading(self, _):
-        if not np.isnan(self.unit_net_value):
-            self._static_unit_net_value = self.unit_net_value
-        else:
-            self._static_unit_net_value = self._last_unit_net_value
+        self._static_unit_net_value = self.unit_net_value
 
-    def _post_settlement(self, event):
-        self._last_unit_net_value = self.unit_net_value
-
-    def _register_event(self):
-        event_bus = Environment.get_instance().event_bus
-        event_bus.prepend_listener(EVENT.PRE_BEFORE_TRADING, self._pre_before_trading)
-        event_bus.prepend_listener(EVENT.POST_SETTLEMENT, self._post_settlement)
+    def deposit_withdraw(self, account_type, amount):
+        """出入金"""
+        # 入金 现金增加，份额增加，总权益增加，单位净值不变
+        # 出金 现金减少，份额减少，总权益减少，单位净值不变
+        if account_type not in self._accounts:
+            raise ValueError(_("invalid account type {}, choose in {}".format(account_type, list(self._accounts.keys()))))
+        unit_net_value = self.unit_net_value
+        self._accounts[account_type].deposit_withdraw(amount)
+        _units = self.total_value / unit_net_value
+        user_log.info(_("Cash add {}. units {} become to {}".format(amount, self._units ,_units)))
+        self._units = _units
 
 
 class MixedPositions(dict):
@@ -280,7 +279,7 @@ class MixedPositions(dict):
     def __repr__(self):
         keys = []
         for account in six.itervalues(self._accounts):
-            keys += account.positions.keys()
+            keys += [order_book_id for order_book_id, position in account.positions.items() if position.quantity > 0]
         return str(sorted(keys))
 
     def __len__(self):
