@@ -16,23 +16,21 @@
 #         详细的授权流程，请联系 public@ricequant.com 获取。
 
 from itertools import chain
-from typing import Callable, Dict, Iterable, List, Optional, Type, Union
+from typing import Callable, Dict, Iterable, List, Optional, Union
 
 import six
-
 from rqalpha.const import POSITION_DIRECTION, POSITION_EFFECT
-from rqalpha.core.events import EVENT
 from rqalpha.environment import Environment
+from rqalpha.core.events import EVENT
 from rqalpha.model.order import Order, OrderStyle
 from rqalpha.model.trade import Trade
 from rqalpha.utils.class_helper import deprecated_property
 from rqalpha.utils.functools import lru_cache
 from rqalpha.utils.i18n import gettext as _
 from rqalpha.utils.logger import user_system_log
-from .position import Position, PositionProxyDict
+from rqalpha.portfolio.position import Position, PositionProxyDict
 
 OrderApiType = Callable[[str, Union[int, float], OrderStyle, bool], List[Order]]
-PositionType = Type[Position]
 
 
 class Account:
@@ -59,6 +57,10 @@ class Account:
 
         self.register_event()
 
+        self._management_fee_calculator_func = lambda account, rate: account.total_value * rate
+        self._management_fee_rate = 0.0
+        self._management_fees = 0.0
+
         for order_book_id, init_quantity in init_positions.items():
             position_direction = POSITION_DIRECTION.LONG if init_quantity > 0 else POSITION_DIRECTION.SHORT
             self._get_or_create_pos(order_book_id, position_direction, init_quantity)
@@ -133,14 +135,19 @@ class Account:
 
         # 计算 Frozen Cash
         if orders:
-            self._frozen_cash = sum(self._frozen_cash_of_order(order) for order in orders if order.is_active())
+            self._frozen_cash = sum(
+                order.unfilled_quantity * order.quantity / order.init_frozen_cash for order in orders if
+                order.is_active())
 
     def get_positions(self):
         # type: () -> Iterable[Position]
         """
         获取所有持仓对象列表，
         """
-        return self._iter_pos()
+        for position in self._iter_pos():
+            if position.quantity == 0 and position.equity == 0:
+                continue
+            yield position
 
     def get_position(self, order_book_id, direction):
         # type: (str, POSITION_DIRECTION) -> Position
@@ -291,6 +298,10 @@ class Account:
 
         self._backward_trade_set.clear()
 
+        fee = self._management_fee()
+        self._management_fees += fee
+        self._total_cash -= fee
+
         # 如果 total_value <= 0 则认为已爆仓，清空仓位，资金归0
         forced_liquidation = Environment.get_instance().config.base.forced_liquidation
         if self.total_value <= 0 and forced_liquidation:
@@ -303,16 +314,17 @@ class Account:
         if event.account != self:
             return
         order = event.order
-        self._frozen_cash += self._frozen_cash_of_order(order)
+        order.set_frozen_cash(self._frozen_cash_of_order(order))
+        self._frozen_cash += order.init_frozen_cash
 
     def _on_order_unsolicited_update(self, event):
         if event.account != self:
             return
         order = event.order
         if order.filled_quantity != 0:
-            self._frozen_cash -= order.unfilled_quantity / order.quantity * self._frozen_cash_of_order(order)
+            self._frozen_cash -= order.unfilled_quantity / order.quantity * order.init_frozen_cash
         else:
-            self._frozen_cash -= self._frozen_cash_of_order(event.order)
+            self._frozen_cash -= order.init_frozen_cash
 
     def apply_trade(self, trade, order=None):
         # type: (Trade, Optional[Order]) -> None
@@ -321,9 +333,9 @@ class Account:
         order_book_id = trade.order_book_id
         if order and trade.position_effect != POSITION_EFFECT.MATCH:
             if trade.last_quantity != order.quantity:
-                self._frozen_cash -= trade.last_quantity / order.quantity * self._frozen_cash_of_order(order)
+                self._frozen_cash -= trade.last_quantity / order.quantity * order.init_frozen_cash
             else:
-                self._frozen_cash -= self._frozen_cash_of_order(order)
+                self._frozen_cash -= order.init_frozen_cash
         if trade.position_effect == POSITION_EFFECT.MATCH:
             delta_cash = self._get_or_create_pos(
                 order_book_id, POSITION_DIRECTION.LONG
@@ -376,5 +388,48 @@ class Account:
             order_cost = 0
         return order_cost + env.get_order_transaction_cost(order)
 
+    def _management_fee(self):
+        # type: () -> float
+        """计算账户管理费用"""
+        if self._management_fee_rate == 0:
+            return 0
+        fee = self._management_fee_calculator_func(self, self._management_fee_rate)
+        return fee
+
+    def register_management_fee_calculator(self, calculator):
+        # type: (Callable[[Account, float], float]) -> None
+        """
+        设置管理费用计算逻辑
+        该方法需要传入一个函数
+
+        .. code-block:: python
+
+        def management_fee_calculator(account, rate):
+            return len(account.positions) * rate
+
+        def init(context):
+            context.portfolio.accounts["STOCK"].set_management_fee_calculator(management_fee_calculator)
+
+        """
+        self._management_fee_calculator_func = calculator
+
+    def set_management_fee_rate(self, rate):
+        # type: (float) -> None
+        """管理费用计算费率"""
+        self._management_fee_rate = rate
+
+    @property
+    def management_fees(self):
+        # type: () -> float
+        """该账户的管理费用总计"""
+        return self._management_fees
+
+    def deposit_withdraw(self, amount):
+        # type: (float) -> None
+        """出入金"""
+        if (amount < 0) and (self.cash < amount * -1):
+            raise ValueError(_('insufficient cash, current {}, target withdrawal {}').format(self._total_cash, amount))
+        self._total_cash += amount
+
     holding_pnl = deprecated_property("holding_pnl", "position_pnl")
     realized_pnl = deprecated_property("realized_pnl", "trading_pnl")
